@@ -1,7 +1,7 @@
 import os
 import re
 from typing import Match
-
+from urllib.parse import quote
 from .types import EzLinksOptions, BrokenLink
 from .scanners.base_link_scanner import BaseLinkScanner
 from .file_mapper import FileMapper
@@ -53,7 +53,6 @@ class EzLinksReplacer:
 
     def _do_replace(self, match: Match) -> str:
         abs_from = os.path.dirname(os.path.join(self.root, self.path))
-
         try:
             for scanner in self.scanners:
                 if scanner.match(match):
@@ -79,7 +78,7 @@ class EzLinksReplacer:
                             raise BrokenLink(f"'{link.target}' not found.")
                         link.target = search_result
 
-                    link.target = os.path.relpath(link.target, abs_from)
+                    link.target = quote(os.path.relpath(link.target, abs_from))
                     return link.render()
         except BrokenLink as ex:
             # Log these out as Debug messages, as the regular mkdocs
